description_BANOVA<-function(){
cat("\n\n")
cat("****************************************************************************\n")
cat("               Statistical analysis (ANOVA(lm), 90%CI...)                   \n")
cat("--------------------------------------------------------------------------  \n")
cat(" With a two-treatment, two-period, two-sequence randomized crossover        \n")
cat(" design, ANOVA statistical model includes factors of the following sources: \n")
cat(" sequence, subjects nested in sequences, period and treatment. ANOVA will  \n")
cat(" be applied to obtain estimates for the adjusted differences between        \n")
cat(" treatment means and the standard error associated with these differences.  \n")
cat(" Log-transformed BA measures will also be analyzed.                         \n")
cat("****************************************************************************\n")
cat("\n\n")
readline(" Press Enter to continue...")
}